@@ -21,25 +21,17 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-
 #include "curl_setup.h"
 
-#include <curl/curl.h>
-#include <curl/mprintf.h>
-
 #ifdef USE_WINDOWS_SSPI
 #include "curl_sspi.h"
 #endif
 
 #include "curlx/winapi.h"
 #include "strerror.h"
+#include "curlx/strcopy.h"
 
-/* The last 2 #include files should be in this order */
-#include "curl_memory.h"
-#include "memdebug.h"
-
-const char *
-curl_easy_strerror(CURLcode error)
+const char *curl_easy_strerror(CURLcode error)
 {
 #ifndef CURL_DISABLE_VERBOSE_STRINGS
   switch(error) {
@@ -57,7 +49,7 @@ curl_easy_strerror(CURLcode error)
 
   case CURLE_NOT_BUILT_IN:
     return "A requested feature, protocol or option was not found built-in in"
-      " this libcurl due to a build-time decision.";
+           " this libcurl due to a build-time decision.";
 
   case CURLE_COULDNT_RESOLVE_PROXY:
     return "Could not resolve proxy name";
@@ -331,8 +323,7 @@ curl_easy_strerror(CURLcode error)
 #endif
 }
 
-const char *
-curl_multi_strerror(CURLMcode error)
+const char *curl_multi_strerror(CURLMcode error)
 {
 #ifndef CURL_DISABLE_VERBOSE_STRINGS
   switch(error) {
@@ -391,8 +382,7 @@ curl_multi_strerror(CURLMcode error)
 #endif
 }
 
-const char *
-curl_share_strerror(CURLSHcode error)
+const char *curl_share_strerror(CURLSHcode error)
 {
 #ifndef CURL_DISABLE_VERBOSE_STRINGS
   switch(error) {
@@ -427,8 +417,7 @@ curl_share_strerror(CURLSHcode error)
 #endif
 }
 
-const char *
-curl_url_strerror(CURLUcode error)
+const char *curl_url_strerror(CURLUcode error)
 {
 #ifndef CURL_DISABLE_VERBOSE_STRINGS
   switch(error) {
@@ -560,98 +549,97 @@ const char *Curl_sspi_strerror(SECURITY_STATUS err, char *buf, size_t buflen)
   *buf = '\0';
 
 #ifndef CURL_DISABLE_VERBOSE_STRINGS
-
   switch(err) {
-    case SEC_E_OK:
-      txt = "No error";
-      break;
+  case SEC_E_OK:
+    txt = "No error";
+    break;
 #define SEC2TXT(sec) case sec: txt = #sec; break
-    SEC2TXT(CRYPT_E_REVOKED);
-    SEC2TXT(CRYPT_E_NO_REVOCATION_DLL);
-    SEC2TXT(CRYPT_E_NO_REVOCATION_CHECK);
-    SEC2TXT(CRYPT_E_REVOCATION_OFFLINE);
-    SEC2TXT(CRYPT_E_NOT_IN_REVOCATION_DATABASE);
-    SEC2TXT(SEC_E_ALGORITHM_MISMATCH);
-    SEC2TXT(SEC_E_BAD_BINDINGS);
-    SEC2TXT(SEC_E_BAD_PKGID);
-    SEC2TXT(SEC_E_BUFFER_TOO_SMALL);
-    SEC2TXT(SEC_E_CANNOT_INSTALL);
-    SEC2TXT(SEC_E_CANNOT_PACK);
-    SEC2TXT(SEC_E_CERT_EXPIRED);
-    SEC2TXT(SEC_E_CERT_UNKNOWN);
-    SEC2TXT(SEC_E_CERT_WRONG_USAGE);
-    SEC2TXT(SEC_E_CONTEXT_EXPIRED);
-    SEC2TXT(SEC_E_CROSSREALM_DELEGATION_FAILURE);
-    SEC2TXT(SEC_E_CRYPTO_SYSTEM_INVALID);
-    SEC2TXT(SEC_E_DECRYPT_FAILURE);
-    SEC2TXT(SEC_E_DELEGATION_POLICY);
-    SEC2TXT(SEC_E_DELEGATION_REQUIRED);
-    SEC2TXT(SEC_E_DOWNGRADE_DETECTED);
-    SEC2TXT(SEC_E_ENCRYPT_FAILURE);
-    SEC2TXT(SEC_E_ILLEGAL_MESSAGE);
-    SEC2TXT(SEC_E_INCOMPLETE_CREDENTIALS);
-    SEC2TXT(SEC_E_INCOMPLETE_MESSAGE);
-    SEC2TXT(SEC_E_INSUFFICIENT_MEMORY);
-    SEC2TXT(SEC_E_INTERNAL_ERROR);
-    SEC2TXT(SEC_E_INVALID_HANDLE);
-    SEC2TXT(SEC_E_INVALID_PARAMETER);
-    SEC2TXT(SEC_E_INVALID_TOKEN);
-    SEC2TXT(SEC_E_ISSUING_CA_UNTRUSTED);
-    SEC2TXT(SEC_E_ISSUING_CA_UNTRUSTED_KDC);
-    SEC2TXT(SEC_E_KDC_CERT_EXPIRED);
-    SEC2TXT(SEC_E_KDC_CERT_REVOKED);
-    SEC2TXT(SEC_E_KDC_INVALID_REQUEST);
-    SEC2TXT(SEC_E_KDC_UNABLE_TO_REFER);
-    SEC2TXT(SEC_E_KDC_UNKNOWN_ETYPE);
-    SEC2TXT(SEC_E_LOGON_DENIED);
-    SEC2TXT(SEC_E_MAX_REFERRALS_EXCEEDED);
-    SEC2TXT(SEC_E_MESSAGE_ALTERED);
-    SEC2TXT(SEC_E_MULTIPLE_ACCOUNTS);
-    SEC2TXT(SEC_E_MUST_BE_KDC);
-    SEC2TXT(SEC_E_NOT_OWNER);
-    SEC2TXT(SEC_E_NO_AUTHENTICATING_AUTHORITY);
-    SEC2TXT(SEC_E_NO_CREDENTIALS);
-    SEC2TXT(SEC_E_NO_IMPERSONATION);
-    SEC2TXT(SEC_E_NO_IP_ADDRESSES);
-    SEC2TXT(SEC_E_NO_KERB_KEY);
-    SEC2TXT(SEC_E_NO_PA_DATA);
-    SEC2TXT(SEC_E_NO_S4U_PROT_SUPPORT);
-    SEC2TXT(SEC_E_NO_TGT_REPLY);
-    SEC2TXT(SEC_E_OUT_OF_SEQUENCE);
-    SEC2TXT(SEC_E_PKINIT_CLIENT_FAILURE);
-    SEC2TXT(SEC_E_PKINIT_NAME_MISMATCH);
-    SEC2TXT(SEC_E_POLICY_NLTM_ONLY);
-    SEC2TXT(SEC_E_QOP_NOT_SUPPORTED);
-    SEC2TXT(SEC_E_REVOCATION_OFFLINE_C);
-    SEC2TXT(SEC_E_REVOCATION_OFFLINE_KDC);
-    SEC2TXT(SEC_E_SECPKG_NOT_FOUND);
-    SEC2TXT(SEC_E_SECURITY_QOS_FAILED);
-    SEC2TXT(SEC_E_SHUTDOWN_IN_PROGRESS);
-    SEC2TXT(SEC_E_SMARTCARD_CERT_EXPIRED);
-    SEC2TXT(SEC_E_SMARTCARD_CERT_REVOKED);
-    SEC2TXT(SEC_E_SMARTCARD_LOGON_REQUIRED);
-    SEC2TXT(SEC_E_STRONG_CRYPTO_NOT_SUPPORTED);
-    SEC2TXT(SEC_E_TARGET_UNKNOWN);
-    SEC2TXT(SEC_E_TIME_SKEW);
-    SEC2TXT(SEC_E_TOO_MANY_PRINCIPALS);
-    SEC2TXT(SEC_E_UNFINISHED_CONTEXT_DELETED);
-    SEC2TXT(SEC_E_UNKNOWN_CREDENTIALS);
-    SEC2TXT(SEC_E_UNSUPPORTED_FUNCTION);
-    SEC2TXT(SEC_E_UNSUPPORTED_PREAUTH);
-    SEC2TXT(SEC_E_UNTRUSTED_ROOT);
-    SEC2TXT(SEC_E_WRONG_CREDENTIAL_HANDLE);
-    SEC2TXT(SEC_E_WRONG_PRINCIPAL);
-    SEC2TXT(SEC_I_COMPLETE_AND_CONTINUE);
-    SEC2TXT(SEC_I_COMPLETE_NEEDED);
-    SEC2TXT(SEC_I_CONTEXT_EXPIRED);
-    SEC2TXT(SEC_I_CONTINUE_NEEDED);
-    SEC2TXT(SEC_I_INCOMPLETE_CREDENTIALS);
-    SEC2TXT(SEC_I_LOCAL_LOGON);
-    SEC2TXT(SEC_I_NO_LSA_CONTEXT);
-    SEC2TXT(SEC_I_RENEGOTIATE);
-    SEC2TXT(SEC_I_SIGNATURE_NEEDED);
-    default:
-      txt = "Unknown error";
+  SEC2TXT(CRYPT_E_REVOKED);
+  SEC2TXT(CRYPT_E_NO_REVOCATION_DLL);
+  SEC2TXT(CRYPT_E_NO_REVOCATION_CHECK);
+  SEC2TXT(CRYPT_E_REVOCATION_OFFLINE);
+  SEC2TXT(CRYPT_E_NOT_IN_REVOCATION_DATABASE);
+  SEC2TXT(SEC_E_ALGORITHM_MISMATCH);
+  SEC2TXT(SEC_E_BAD_BINDINGS);
+  SEC2TXT(SEC_E_BAD_PKGID);
+  SEC2TXT(SEC_E_BUFFER_TOO_SMALL);
+  SEC2TXT(SEC_E_CANNOT_INSTALL);
+  SEC2TXT(SEC_E_CANNOT_PACK);
+  SEC2TXT(SEC_E_CERT_EXPIRED);
+  SEC2TXT(SEC_E_CERT_UNKNOWN);
+  SEC2TXT(SEC_E_CERT_WRONG_USAGE);
+  SEC2TXT(SEC_E_CONTEXT_EXPIRED);
+  SEC2TXT(SEC_E_CROSSREALM_DELEGATION_FAILURE);
+  SEC2TXT(SEC_E_CRYPTO_SYSTEM_INVALID);
+  SEC2TXT(SEC_E_DECRYPT_FAILURE);
+  SEC2TXT(SEC_E_DELEGATION_POLICY);
+  SEC2TXT(SEC_E_DELEGATION_REQUIRED);
+  SEC2TXT(SEC_E_DOWNGRADE_DETECTED);
+  SEC2TXT(SEC_E_ENCRYPT_FAILURE);
+  SEC2TXT(SEC_E_ILLEGAL_MESSAGE);
+  SEC2TXT(SEC_E_INCOMPLETE_CREDENTIALS);
+  SEC2TXT(SEC_E_INCOMPLETE_MESSAGE);
+  SEC2TXT(SEC_E_INSUFFICIENT_MEMORY);
+  SEC2TXT(SEC_E_INTERNAL_ERROR);
+  SEC2TXT(SEC_E_INVALID_HANDLE);
+  SEC2TXT(SEC_E_INVALID_PARAMETER);
+  SEC2TXT(SEC_E_INVALID_TOKEN);
+  SEC2TXT(SEC_E_ISSUING_CA_UNTRUSTED);
+  SEC2TXT(SEC_E_ISSUING_CA_UNTRUSTED_KDC);
+  SEC2TXT(SEC_E_KDC_CERT_EXPIRED);
+  SEC2TXT(SEC_E_KDC_CERT_REVOKED);
+  SEC2TXT(SEC_E_KDC_INVALID_REQUEST);
+  SEC2TXT(SEC_E_KDC_UNABLE_TO_REFER);
+  SEC2TXT(SEC_E_KDC_UNKNOWN_ETYPE);
+  SEC2TXT(SEC_E_LOGON_DENIED);
+  SEC2TXT(SEC_E_MAX_REFERRALS_EXCEEDED);
+  SEC2TXT(SEC_E_MESSAGE_ALTERED);
+  SEC2TXT(SEC_E_MULTIPLE_ACCOUNTS);
+  SEC2TXT(SEC_E_MUST_BE_KDC);
+  SEC2TXT(SEC_E_NOT_OWNER);
+  SEC2TXT(SEC_E_NO_AUTHENTICATING_AUTHORITY);
+  SEC2TXT(SEC_E_NO_CREDENTIALS);
+  SEC2TXT(SEC_E_NO_IMPERSONATION);
+  SEC2TXT(SEC_E_NO_IP_ADDRESSES);
+  SEC2TXT(SEC_E_NO_KERB_KEY);
+  SEC2TXT(SEC_E_NO_PA_DATA);
+  SEC2TXT(SEC_E_NO_S4U_PROT_SUPPORT);
+  SEC2TXT(SEC_E_NO_TGT_REPLY);
+  SEC2TXT(SEC_E_OUT_OF_SEQUENCE);
+  SEC2TXT(SEC_E_PKINIT_CLIENT_FAILURE);
+  SEC2TXT(SEC_E_PKINIT_NAME_MISMATCH);
+  SEC2TXT(SEC_E_POLICY_NLTM_ONLY);
+  SEC2TXT(SEC_E_QOP_NOT_SUPPORTED);
+  SEC2TXT(SEC_E_REVOCATION_OFFLINE_C);
+  SEC2TXT(SEC_E_REVOCATION_OFFLINE_KDC);
+  SEC2TXT(SEC_E_SECPKG_NOT_FOUND);
+  SEC2TXT(SEC_E_SECURITY_QOS_FAILED);
+  SEC2TXT(SEC_E_SHUTDOWN_IN_PROGRESS);
+  SEC2TXT(SEC_E_SMARTCARD_CERT_EXPIRED);
+  SEC2TXT(SEC_E_SMARTCARD_CERT_REVOKED);
+  SEC2TXT(SEC_E_SMARTCARD_LOGON_REQUIRED);
+  SEC2TXT(SEC_E_STRONG_CRYPTO_NOT_SUPPORTED);
+  SEC2TXT(SEC_E_TARGET_UNKNOWN);
+  SEC2TXT(SEC_E_TIME_SKEW);
+  SEC2TXT(SEC_E_TOO_MANY_PRINCIPALS);
+  SEC2TXT(SEC_E_UNFINISHED_CONTEXT_DELETED);
+  SEC2TXT(SEC_E_UNKNOWN_CREDENTIALS);
+  SEC2TXT(SEC_E_UNSUPPORTED_FUNCTION);
+  SEC2TXT(SEC_E_UNSUPPORTED_PREAUTH);
+  SEC2TXT(SEC_E_UNTRUSTED_ROOT);
+  SEC2TXT(SEC_E_WRONG_CREDENTIAL_HANDLE);
+  SEC2TXT(SEC_E_WRONG_PRINCIPAL);
+  SEC2TXT(SEC_I_COMPLETE_AND_CONTINUE);
+  SEC2TXT(SEC_I_COMPLETE_NEEDED);
+  SEC2TXT(SEC_I_CONTEXT_EXPIRED);
+  SEC2TXT(SEC_I_CONTINUE_NEEDED);
+  SEC2TXT(SEC_I_INCOMPLETE_CREDENTIALS);
+  SEC2TXT(SEC_I_LOCAL_LOGON);
+  SEC2TXT(SEC_I_NO_LSA_CONTEXT);
+  SEC2TXT(SEC_I_RENEGOTIATE);
+  SEC2TXT(SEC_I_SIGNATURE_NEEDED);
+  default:
+    txt = "Unknown error";
   }
 
   if(err == SEC_E_ILLEGAL_MESSAGE) {
@@ -668,14 +656,12 @@ const char *Curl_sspi_strerror(SECURITY_STATUS err, char *buf, size_t buflen)
     else
       curl_msnprintf(buf, buflen, "%s (0x%08lx)", txt, err);
   }
-
 #else
   if(err == SEC_E_OK)
     txt = "No error";
   else
     txt = "Error";
-  if(buflen > strlen(txt))
-    strcpy(buf, txt);
+  curlx_strcopy(buf, buflen, txt, strlen(txt));
 #endif
 
   if(errno != old_errno)
